<?PHP
/*
Plugin Name: WordPress Reusables
Plugin URI: http://www.ooeygui.net
Description: WordPress Reusables was created to help developers manage their content more efficiently. By allowing content to be stored and edited in a single location on WordPress it is possible to update a single piece of content that will update retroactively anywhere that the reusable is being used. This plugin creates a more front-end approach to templatizing content and even makes it possible to create or modify an entire theme without touching the PHP code.
Version: 2.0
Author: Ian Whitcomb
Author URI: http://www.ooeygui.net
*/

global $user_level;
global $wpdb;
$wpdb->reus = $wpdb->prefix."reus";

global $plug;
$plug["directory"] = basename(dirname(__FILE__)); 	// Plugin Directory
$plug["filename"] = basename(__FILE__); 			// Plugin File

$_REQUEST["f"] = ($_REQUEST["f"] != null) ? $_REQUEST["f"] : (($_REQUEST["action"] != null) ? $_REQUEST["action"] : (($_REQUEST["action2"] != null) ? $_REQUEST["action2"] : null)); 


/* Add admin menu */
add_action("admin_menu", "init_reus_menu");

function init_reus_menu() {

	global $plug;

	if (function_exists("add_menu_page")) {
		add_menu_page(__("Edit Reusables"), __("Reusables"), 2, $plug["directory"]."/edit.php", "", plugins_url($plug["directory"]."/images/icon.png"));
	}
	if (function_exists("add_submenu_page")) {
		add_submenu_page($plug["directory"]."/edit.php", __("Reusables"), __("Edit"), 2, $plug["directory"]."/edit.php", "fn_reus_edit");
		add_submenu_page($plug["directory"]."/edit.php", __("Reusables"), __("Add New"), 2, $plug["directory"]."/new.php", "fn_reus_new");
		add_submenu_page($plug["directory"]."/edit.php", __("Reusables"), __("About"), 2, $plug["directory"]."/about.php", "fn_reus_about");
	}
}

function fn_reus_edit() {

	global $plug;

	include_once(ABSPATH."wp-content/plugins/".$plug["directory"]."/header.php");
	
	switch($_REQUEST["f"]){
		case "insert" :
			$page = "insert";
			break;
		case "preview" :
			$page = "preview";
			break;
		case "modify" :
			$page = "modify";
			break;
		case "save" :
			$page = "modify";
			include_once(ABSPATH."wp-content/plugins/".$plug["directory"]."/save.php");				
			break;
		case "delete" :
			$page = "edit";
			include_once(ABSPATH."wp-content/plugins/".$plug["directory"]."/delete.php");
			break;
		default :
			$page = "edit";
			break;
	}
	
	include_once(ABSPATH."wp-content/plugins/".$plug["directory"]."/$page.php");
	include_once(ABSPATH."wp-content/plugins/".$plug["directory"]."/footer.php");
	
}
function fn_reus_new() {

	global $plug;

	include_once(ABSPATH."wp-content/plugins/".$plug["directory"]."/header.php");
	
	switch($_REQUEST["f"]){
		case "save" :
			$page = "new";
			include_once(ABSPATH."wp-content/plugins/".$plug["directory"]."/save.php");				
			break;
		default :
			$page = "new";
			break;
	}
	
	include_once(ABSPATH."wp-content/plugins/".$plug["directory"]."/$page.php");
	include_once(ABSPATH."wp-content/plugins/".$plug["directory"]."/footer.php");
	
}

function fn_reus_about() {

	global $plug;

	include_once(ABSPATH."wp-content/plugins/".$plug["directory"]."/header.php");
	include_once(ABSPATH."wp-content/plugins/".$plug["directory"]."/about.php");
	include_once(ABSPATH."wp-content/plugins/".$plug["directory"]."/footer.php");
	
}


/* Add TinyMCE reusables button */
add_action("init", "init_reus_icon");

function init_reus_icon() {

	global $user_level;

	if($user_level > 1 and !current_user_can("edit_posts") and ! current_user_can("edit_pages")) {
		return;
	}
	if(get_user_option("rich_editing") == "true") {
		add_filter("mce_external_plugins", "tinymc_add_reus_bttn");
		add_filter("mce_buttons", "tinymce_reg_reus_bttn");
	}
}
function tinymce_reg_reus_bttn($buttons) {
	array_push($buttons, "separator", "reus");
	return $buttons;
}
function tinymc_add_reus_bttn($plug_array) {
	
	global $plug;

	$plug_array["reus"] = plugins_url($plug["directory"]."/tinymce.reus.js.php?directory=".$plug["directory"]);
	return $plug_array;
}


/* Correct issues with the TinyMCE editor. */
add_filter('admin_head','zd_multilang_tinymce');

function zd_multilang_tinymce() {
	wp_admin_css('thickbox');
	wp_print_scripts('jquery-ui-core');
	wp_print_scripts('jquery-ui-tabs');
	wp_print_scripts('post');
	wp_print_scripts('editor');
	add_thickbox();
	wp_print_scripts('media-upload');
	if (function_exists('wp_tiny_mce')) wp_tiny_mce();
	// use the if condition because this function doesn't exist in version prior to 2.7
}


/* Setup the "reus" shortcode

[reus (name="str"|id="int")[ meta="var1=one&var2=two"]]

[reus id="6" vars="subhead=Lorem ipsum dolor sit amet.&headline=Lipsum&url=http://www.test.com"]

<h1>@headline</h1>
<h2>@subhead</h2>

*/
add_shortcode("reus", "setup_reus_tag");

function setup_reus_tag($attr){
	
	extract($attr);
	
	if(!$name and $id){
		$reus = get_reus($id, $meta);
	} 
	elseif($name){
		$reus = get_reus($name, $meta);
	}
	else {
		$reus = "";
	}
	
	return $reus;

}

/* Setup template functions

<?PHP echo get_reus("str"|int,["var1=one&var2=two"]); ?>

*/
function get_reus($id, $meta = null){

	global $wpdb;

	if(is_numeric($id)){
		$reus = $wpdb->get_var("SELECT reus_content FROM $wpdb->reus WHERE reus_id = $id;");
	} else {
		$reus = $wpdb->get_var("SELECT reus_content FROM $wpdb->reus WHERE reus_name = '$id';");
	}
	
	if(isset($meta)){
		$vars = explode("&",html_entity_decode($meta));
		foreach($vars as $var){
			list($key, $val) = split("=",$var);
			$reus = str_ireplace("%$key%", $val, $reus);
		}
	}
	
	$reus = stripslashes($reus);
	
	preg_match_all('/\\[\\s*reus\\s*([a-zA-Z0-9_\-]*=["|\']?[a-zA-Z0-9_\-&\=\\s]*["|\']?)?\\s*([a-zA-Z0-9_\-]*=["|\']?[a-zA-Z0-9_\-&\=\\s]*["|\']?)?\\s*([a-zA-Z0-9_\-]*=["|\']?[a-zA-Z0-9_\-&\=\\s]*["|\']?)?\\s*]/',$reus,$matches);
	foreach($matches[0] as $key => $value){
		if(preg_match('/(id|name)=["|\']?([a-zA-Z0-9_\-\\s]*)["|\']?/',$value,$has_id)){
			
			$id = ($has_id[array_search("name",$has_id)+1]) ? $has_id[array_search("name",$has_id)+1] : $has_id[array_search("id",$has_id)+1];
			
			if(preg_match('/meta=["|\']?([a-zA-Z0-9_\-\\s=&]*)["|\']?/',$value,$has_meta)){
				$meta = $has_meta[1];
			}
			
			$reus = str_replace($value,get_reus($id,$meta),$reus);
			
		}
	}
		
	return $reus;
	
}


/* Setup reusables database structure */
add_action("activate_".$plug["directory"]."/".$plug["filename"], "setup_reus_db");

function setup_reus_db(){

	global $wpdb;
	
	if(@is_file(ABSPATH."/wp-admin/upgrade-functions.php")) {
		include_once(ABSPATH."/wp-admin/upgrade-functions.php");
	} elseif(@is_file(ABSPATH."/wp-admin/includes/upgrade.php")) {
		include_once(ABSPATH."/wp-admin/includes/upgrade.php");
	} else {
		die("Unable to locate \"wp-admin/upgrade-functions.php\" and/or \"wp-admin/includes/upgrade.php\"");
	}

	$charset_collate = "";
	if($wpdb->supports_collation()) {
		if(!empty($wpdb->charset)) {
			$charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
		}
		if(!empty($wpdb->collate)) {
			$charset_collate .= " COLLATE $wpdb->collate";
		}
	}
	
	/* wp_reus */
	$tbl["reus"] = "CREATE TABLE $wpdb->reus (" .
				   "reus_id bigint(20) NOT NULL auto_increment," .
				   "reus_name varchar(128) NOT NULL," .
				   "reus_content longtext," .
				   " reus_description varchar(512) default NULL," .
				   "reus_author bigint(20) unsigned NOT NULL default '0'," .
				   "reus_last_modified timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP," .
				   "PRIMARY KEY  (reus_id)," .
				   "UNIQUE KEY reus_name (reus_name)" .
				   ") $charset_collate;";
				   
	echo $tbl["reus"];
			 
	maybe_create_table($wpdb->reus, $tbl["reus"]);


	/* For upgrading from 1.0 to 2.0 */	
	$wpdb->query("ALTER TABLE wp_reus ADD reus_description VARCHAR( 512 ) NULL AFTER reus_content;");
	
	/*
	$wpdb->insert($wpdb->reus, array("reus_name" => "Hello world"), array("%s","%d"));
	$wpdb->update($wpdb->reus, array("reus_content" => "This is a reusable. You can add this to your pages and posts by using the <strong>reus</strong> shortcode along with the <strong>name</strong> attribute.\r\nFor example, <strong>[reus name=\"Hello world\"]</strong> will display all of the content from this reusable on any page or post.", "reus_description" => "This is an example reusable.", "reus_author" => 1), array("reus_name" => "Hello world"));
	*/
	
}


?>